pub struct SkeletonKvTable<'a> { /* private fields */ }Expand description
Skeleton key-value table (properties panel / detail view).
Renders pairs of short fixed-width keys on the left and
variable-width values on the right, separated by a dim │.
Each pair occupies one row with a gap row between pairs.
Implementations
Sourceimpl<'a> SkeletonKvTable<'a>
impl<'a> SkeletonKvTable<'a>
pub fn new(elapsed_ms: u64) -> Self
pub fn mode(self, mode: AnimationMode) -> Self
pub fn braille(self, braille: bool) -> Self
pub fn base(self, color: impl Into<Color>) -> Self
pub fn highlight(self, color: impl Into<Color>) -> Self
Sourcepub fn key_width(self, width: u16) -> Self
pub fn key_width(self, width: u16) -> Self
Fixed width of the key column in cells. Default: 12.
Sourcepub fn value_widths(self, widths: &'a [f32]) -> Self
pub fn value_widths(self, widths: &'a [f32]) -> Self
Per-pair value width fractions (0.0..=1.0) of the remaining space.
The pattern cycles when there are more pairs than entries.
pub fn block(self, block: Block<'a>) -> Self